//: ©2016 John Haney, All Rights Reserved
//: 
//: [Previous](@previous)
//:
//: # Year Of Swift
//: ### Picture Time
//:
//: Now that we've learned enough different pieces of Swift, let's do something more fun and a little artsy.

//: We're going to use some specific iOS (iPhone, iPad) classes to draw a few pictures.
//:
//: First, we import UIKit, which has all sorts of cool stuff we can use for drawing things on the screen.
import UIKit

//: Let's make a function that will return a circle UIView. We're going to make a few circles today.
func circleAt(x x: CGFloat, y: CGFloat, radius: CGFloat) -> UIView
{
    let diameter = radius * 2
    let view = UIView(frame: CGRect(x: x - radius, y: y - radius, width: diameter, height: diameter))
    view.layer.cornerRadius = radius
    return view
}

//: CGRect is a struct. You know about structs. CGRect is how you can make a rectangle, by giving the CGRect a top-left corner, width, and height. On iOS devices (iPhones, iPads, etc.), the top-left corner of the screen is where x is zero and y is zero. Remember, computers like to start at zero. The top-right corner will be at some bigger number of x that depends on which iPhone or iPad you're running on, and which way the user is holding it! For our little playground here, we don't care about the screen. We're just making some UIViews. UIView is a class. We'll talk more about classes later. Everything that you'll show on an iPhone or iPad is a UIView. Well, there are other ways, but for now, let's just stick to UIViews. A UIView is an item that can be seen on a screen. Buttons that you can tap are UIViews, any words on the screen are UIViews, anything you actually see in an app is some kind of a UIView.

let circlesView = UIView(frame: CGRect(x: 0, y: 0, width: 400, height: 300))
circlesView.layer.borderColor = UIColor.blackColor().CGColor
circlesView.layer.borderWidth = 2
circlesView.backgroundColor = UIColor.whiteColor()

let leftCircle = circleAt(x: 170, y: 170, radius: 100)
leftCircle.backgroundColor = UIColor.magentaColor().colorWithAlphaComponent(0.5)
circlesView.addSubview(leftCircle)
// If you don't see a picture right above this, then click on the circle for the line above, the circle is all the way to the right, over there next to where it says UIView ---->

let rightCircle = circleAt(x: 230, y: 170, radius: 100)
rightCircle.backgroundColor = UIColor.cyanColor().colorWithAlphaComponent(0.5)
circlesView.addSubview(rightCircle)
// If you don't see a picture above, then click on the circle over there ---->
let topCircle = circleAt(x: 200, y: 130, radius: 100)
topCircle.backgroundColor = UIColor.yellowColor().colorWithAlphaComponent(0.5)
circlesView.addSubview(topCircle)
// If you don't see a picture above, then click on the circle over there ---->

let concentricView = circleAt(x: 150, y: 150, radius: 150)
concentricView.backgroundColor = UIColor.redColor()
let orange = circleAt(x: 150, y: 150, radius: 120)
orange.backgroundColor = UIColor.orangeColor()
let yellow = circleAt(x: 150, y: 150, radius: 90)
yellow.backgroundColor = UIColor.yellowColor()
let green = circleAt(x: 150, y: 150, radius: 60)
green.backgroundColor = UIColor.greenColor()
let blue = circleAt(x: 150, y: 150, radius: 30)
blue.backgroundColor = UIColor.blueColor()
concentricView.addSubview(orange)
concentricView.addSubview(yellow)
concentricView.addSubview(green)
concentricView.addSubview(blue)
// If you don't see a picture above, then click on the circle over there ---->

let smiley = circleAt(x: 150, y: 150, radius: 150)
smiley.backgroundColor = UIColor.yellowColor()
let leftEye = circleAt(x: 90, y: 100, radius: 40)
leftEye.backgroundColor = UIColor.blackColor()
let rightEye = circleAt(x: 210, y: 100, radius: 40)
rightEye.backgroundColor = UIColor.blackColor()
let mouth = circleAt(x: 150, y: 210, radius: 20)
mouth.backgroundColor = UIColor.blackColor()
smiley.addSubview(leftEye)
smiley.addSubview(rightEye)
smiley.addSubview(mouth)
// If you don't see a picture above, then click on the circle over there ---->

//: ## Summary
//: We just learned about:
//: * CGRect - a struct used for rectangles and positioning things on a screen
//: * UIView - a class for showing things
//: * layer.cornerRadius is how you round corners on a UIView